@@ -194,7 +194,7 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
     pass
 
 
-def server_websuite(user='webuser', python_version='3.4.2', pypy=True, pypy_version='2.4', compatible=False):
+def server_websuite(user='webuser', python_version='3.4.2', only_pypy=True, pypy_version='2.4', compatible=False):
     run('yum install wget -y')
 
     cmd_useradd(user)
@@ -211,10 +211,10 @@ def server_websuite(user='webuser', python_version='3.4.2', pypy=True, pypy_vers
     io_slowlog('supervisor', user)
     server_supervisor()
 
-    if pypy:
+    if only_pypy:
         py_pypy(pypy_version)
     else:
-        py_python(python_version, compatible=False, pypy=pypy_version)
+        py_python(python_version, compatible=compatible, pypy=pypy_version)
 
     pip('tornadoez')
     pip('pyjwt')
