@@ -3,7 +3,7 @@
 from fabric.api import *
 
 
-def utils_git(proxy=None):
+def utils_git(proxy=None,ignore_perm=True):
     '''
     Install git
     :param proxy:proxy server
@@ -14,6 +14,9 @@ def utils_git(proxy=None):
     if proxy:
         run('git config --global http.proxy {}'.format(proxy))
 
+    if ignore_perm:
+        run('git config --global core.fileMode false')
+
     pass
 
 
@@ -37,7 +40,7 @@ def utils_baselib():
     :return:
     '''
     run(
-        'yum install gcc-c++ make zlib-devel libxml2  libxml2-devel  bzip2-libs bzip2-devel  libcurl-devel  libjpeg libjpeg-devel  libpng libpng-devel  freetype freetype-devel  libmcrypt libmcrypt-devel  libtool-ltdl libtool-ltdl-devel openssl-devel autoconf re2c bison pcre_devel pcre -y')
+        'yum install gcc-c++ make zlib-devel libxml2  libxml2-devel  bzip2-libs bzip2-devel  libcurl-devel  libjpeg libjpeg-devel  libpng libpng-devel  freetype freetype-devel  libmcrypt libmcrypt-devel  libtool-ltdl libtool-ltdl-devel openssl-devel autoconf re2c bison pcre_devel pcre   libtiff-devel libjpeg-devel libzip-devel freetype-devel lcms2-devel libwebp-devel tcl-devel tk-devel -y')
     run('mkdir -p /usr/local/var/run')
     pass
 
@@ -56,6 +59,18 @@ def utils_epel():
 
 
 
+def utils_remi():
+    """
+    install epel lib
+    :return:
+    """
+    with settings(warn_only=True):
+        run('rpm -Uvh http://rpms.famillecollet.com/enterprise/remi-release-6.rpm')
+    pass
+
+
+
+
 def utils_hg(proxy=None):
     '''
     Install Mercurial
@@ -66,3 +81,5 @@ def utils_hg(proxy=None):
 
     pass
 
+
+
